@@ -1,5 +1,5 @@
 /*
-   copyright 20016-2017 Paul Dreik (earlier Paul Sundvall)
+   copyright 2006-2017 Paul Dreik (earlier Paul Sundvall)
    Distributed under GPL v 2.0 or later, at your option.
    See LICENSE for further details.
 */
@@ -38,18 +38,18 @@ Dirlist::walk(const std::string& dir, const int recursionlevel)
 
   // open the directory
   DIR* dirp = opendir(dir.c_str());
-  if (dirp == NULL) {
+  if (dirp == nullptr) {
     // failed to open directory
     RDDEBUG("failed to open directory" << std::endl);
     // this can be due to rights, or some other error.
     handlepossiblefile(dir, recursionlevel);
-    return 1; // its a file (or something else)
+    return 1; // it's a file (or something else)
   }
 
   // we opened the directory. let us read the content.
   RDDEBUG("opened directory" << std::endl);
-  struct dirent* dp = NULL;
-  while (NULL != (dp = readdir(dirp))) {
+  struct dirent* dp{};
+  while (nullptr != (dp = readdir(dirp))) {
     // is the directory . or ..?
     if (0 == strcmp(".", dp->d_name) || 0 == strcmp("..", dp->d_name)) {
       continue;
@@ -71,8 +71,6 @@ Dirlist::walk(const std::string& dir, const int recursionlevel)
       // symlink
       if (m_followsymlinks) {
         (*m_callback)(dir, std::string(dp->d_name), recursionlevel);
-      }
-      if (m_followsymlinks) {
         dowalk = true;
       }
     } else if (S_ISDIR(info.st_mode)) {
@@ -92,7 +90,7 @@ Dirlist::walk(const std::string& dir, const int recursionlevel)
 
   // close the directory
   (void)closedir(dirp);
-  return 2; // its a directory
+  return 2; // it's a directory
 }
 
 // splits inputstring into path and filename. if no / character is found,
@@ -120,7 +118,6 @@ splitfilename(std::string& path,
 int
 Dirlist::handlepossiblefile(const std::string& possiblefile, int recursionlevel)
 {
-  struct stat info;
 
   RDDEBUG("Now in handlepossiblefile with name "
           << possiblefile.c_str() << " and recursionlevel " << recursionlevel
@@ -135,6 +132,7 @@ Dirlist::handlepossiblefile(const std::string& possiblefile, int recursionlevel)
 
   // investigate what kind of file it is, dont follow symlink
   int statval = 0;
+  struct stat info;
   do {
     statval = lstat(possiblefile.c_str(), &info);
   } while (statval < 0 && errno == EINTR);
