@@ -1,5 +1,5 @@
 /*
-   copyright 20016-2017 Paul Dreik (earlier Paul Sundvall)
+   copyright 2006-2017 Paul Dreik (earlier Paul Sundvall)
    Distributed under GPL v 2.0 or later, at your option.
    See LICENSE for further details.
 */
@@ -48,7 +48,7 @@ Fileinfo::fillwithbytes(enum readtobuffermode filltype,
     return -1;
   }
 
-  int checksumtype = Checksum::NOTSET;
+  auto checksumtype = Checksum::NOTSET;
   // read some bytes
   switch (filltype) {
     case readtobuffermode::READ_FIRST_BYTES:
@@ -75,10 +75,8 @@ Fileinfo::fillwithbytes(enum readtobuffermode filltype,
   }
 
   if (checksumtype != Checksum::NOTSET) {
-    Checksum chk;
-    if (chk.init(checksumtype)) {
-      std::cerr << "error in checksum init" << std::endl;
-    }
+    Checksum chk(checksumtype);
+
     char buffer[4096];
     while (f1) {
       f1.read(buffer, sizeof(buffer));
@@ -146,7 +144,7 @@ Fileinfo::getduptypestring(const Fileinfo& A)
     case duptype::DUPTYPE_OUTSIDE_TREE:
       return "DUPTYPE_OUTSIDE_TREE";
     default:
-      assert("we should not get here!" != nullptr);
+      assert("we should not get here!" == nullptr);
   }
 
   return "error-error";
@@ -260,7 +258,7 @@ transactional_operation(const std::string& filename, const Func& f)
 
   return 0;
 }
-} // anon. namespace
+} // namespace
 
 // makes a symlink that points to A
 int
